"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@heroku-cli/command");
const cli_ux_1 = require("cli-ux");
const base_1 = require("../../../../base");
const fetcher_1 = require("../../../../lib/fetcher");
class EndpointsAccessIndex extends base_1.default {
    async run() {
        const { args, flags } = this.parse(EndpointsAccessIndex);
        const database = await fetcher_1.default(this.heroku, args.database, flags.app);
        const { body: { allowed_accounts } } = await this.shogun.get(`/private-link/v0/databases/${database}`, this.shogun.defaults);
        if (allowed_accounts.length > 0) {
            cli_ux_1.cli.table(allowed_accounts, {
                arn: {
                    header: 'ARN'
                },
                status: {
                    header: 'Status'
                }
            });
        }
        else {
            cli_ux_1.cli.error('There are no allowed accounts');
        }
    }
}
EndpointsAccessIndex.description = 'list all allowed accounts for your privatelink endpoint';
EndpointsAccessIndex.aliases = ['pg:privatelink:access', 'kafka:privatelink:access', 'redis:privatelink:access'];
EndpointsAccessIndex.args = [
    { name: 'database' },
];
EndpointsAccessIndex.flags = {
    app: command_1.flags.app({ required: true })
};
EndpointsAccessIndex.examples = [
    '$ heroku data:privatelink:access postgresql-sushi-12345',
];
exports.default = EndpointsAccessIndex;
