"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@heroku-cli/command");
const cli_ux_1 = require("cli-ux");
const base_1 = require("../../../../base");
const fetcher_1 = require("../../../../lib/fetcher");
class EndpointsAccessRemove extends base_1.default {
    async run() {
        const { args, flags } = this.parse(EndpointsAccessRemove);
        const database = await fetcher_1.default(this.heroku, args.database, flags.app);
        const account_ids = flags['aws-account-id'];
        const accountFormatted = account_ids.length > 1 ? 'accounts' : 'account';
        cli_ux_1.cli.action.start(`Removing ${accountFormatted}`);
        await this.shogun.patch(`/private-link/v0/databases/${database}/allowed_accounts`, Object.assign({}, this.shogun.defaults, { body: {
                allowed_accounts: account_ids
            } }));
        cli_ux_1.cli.action.stop();
    }
}
EndpointsAccessRemove.description = 'remove an allowed account from your privatelink endpoint';
EndpointsAccessRemove.aliases = ['pg:privatelink:access:remove', 'kafka:privatelink:access:remove', 'redis:privatelink:access:remove'];
EndpointsAccessRemove.args = [
    { name: 'database' },
];
EndpointsAccessRemove.flags = {
    'aws-account-id': command_1.flags.build({
        char: 'i',
        description: 'AWS account id to use',
        parse: (input, ctx) => {
            if (!ctx.endpoints_access_remove_ids)
                ctx.endpoints_access_remove_ids = [];
            ctx.endpoints_access_remove_ids.push(input);
            return ctx.endpoints_access_remove_ids;
        },
    })(),
    app: command_1.flags.app({ required: true })
};
EndpointsAccessRemove.examples = [
    '$ heroku data:privatelink:access:remove postgresql-sushi-12345 --aws-account-id 123456789012:user/xyz',
    '$ heroku data:privatelink:access:remove postgresql-sushi-12345 --aws-account-id 123456789012:user/abc --aws-account-id 123456789012:user/xyz',
];
exports.default = EndpointsAccessRemove;
