"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const color_1 = require("@heroku-cli/color");
const command_1 = require("@heroku-cli/command");
const cli_ux_1 = require("cli-ux");
const base_1 = require("../../../base");
const fetcher_1 = require("../../../lib/fetcher");
class EndpointsCreate extends base_1.default {
    async run() {
        const { args, flags } = this.parse(EndpointsCreate);
        const database = await fetcher_1.default(this.heroku, args.database, flags.app);
        const account_ids = flags['aws-account-id'];
        cli_ux_1.cli.action.start('Creating privatelink endpoint');
        const { body: res } = await this.shogun.post(`/private-link/v0/databases/${database}`, Object.assign({}, this.shogun.defaults, { body: {
                allowed_accounts: account_ids
            } }));
        cli_ux_1.cli.action.stop();
        this.log();
        cli_ux_1.cli.styledObject({
            Status: res.status,
            'Service Name': res.service_name || 'Provisioning'
        });
        this.log();
        this.log(`The privatelink endpoint is now being provisioned for ${color_1.default.cyan(database)}.`);
        this.log('Run ' + color_1.default.cyan('heroku data:privatelink:wait ' + database + ' --app ' + flags.app) +
            ' to check the creation process.');
    }
}
EndpointsCreate.description = 'create a new privatelink endpoint for your database';
EndpointsCreate.aliases = ['pg:privatelink:create', 'kafka:privatelink:create', 'redis:privatelink:create'];
EndpointsCreate.args = [
    { name: 'database' },
];
EndpointsCreate.flags = {
    'aws-account-id': command_1.flags.build({
        char: 'i',
        description: 'AWS account id to use',
        parse: (input, ctx) => {
            if (!ctx.endpoints_create_ids)
                ctx.endpoints_create_ids = [];
            ctx.endpoints_create_ids.push(input);
            return ctx.endpoints_create_ids;
        },
    })(),
    app: command_1.flags.app({ required: true })
};
EndpointsCreate.examples = [
    '$ heroku data:privatelink:create postgresql-sushi-12345 --aws-account-id 123456789012:user/abc',
    '$ heroku data:privatelink:create postgresql-sushi-12345 --aws-account-id 123456789012:user/abc --account-id 123456789012:user/xyz',
];
exports.default = EndpointsCreate;
