"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const color_1 = require("@heroku-cli/color");
const command_1 = require("@heroku-cli/command");
const cli_ux_1 = require("cli-ux");
const base_1 = require("../../../base");
const addontype_1 = require("../../../lib/addontype");
const fetcher_1 = require("../../../lib/fetcher");
class EndpointsIndex extends base_1.default {
    async run() {
        const { args, flags } = this.parse(EndpointsIndex);
        const database = await fetcher_1.default(this.heroku, args.database, flags.app);
        const { body: res } = await this.shogun.get(`/private-link/v0/databases/${database}`, this.shogun.defaults);
        const addonType = await addontype_1.default(res.addon.name);
        if (res.status === 'Provisioning') {
            this.log();
            this.log(`The privatelink endpoint is now being provisioned for ${color_1.default.cyan(database)}.`);
            this.log(`Run ${color_1.default.cyan('heroku data:privatelink:wait -a APP')} to check the creation process.`);
        }
        else {
            cli_ux_1.cli.styledHeader(`privatelink endpoint status for ${color_1.default.cyan(database)}`);
            cli_ux_1.cli.styledObject({
                Status: res.status,
                'Service Name': res.service_name || 'Provisioning',
            });
            if (res && res.allowed_accounts.length > 0) {
                this.log();
                cli_ux_1.cli.styledHeader('Allowed Accounts');
                cli_ux_1.cli.table(res.allowed_accounts, {
                    arn: { header: 'ARN' },
                    status: {}
                });
            }
            this.log();
            if (res && res.connections.length > 0) {
                cli_ux_1.cli.styledHeader('Connections');
                cli_ux_1.cli.table(res.connections, {
                    endpoint_id: { header: 'Endpoint ID' },
                    owner_arn: { header: 'Owner ARN' },
                    status: {}
                });
            }
            else if (res.status === 'Operational' && res.connections.length === 0) {
                this.log('Your privatelink endpoint is now operational.');
                this.log(`You must now copy the ${color_1.default.cyan('Service Name')} and follow the rest of the steps listed in https://devcenter.heroku.com/articles/heroku-${addonType}-via-privatelink`);
            }
        }
    }
}
EndpointsIndex.description = 'list all your privatelink endpoints!';
EndpointsIndex.aliases = ['pg:privatelink', 'kafka:privatelink', 'redis:privatelink'];
EndpointsIndex.args = [
    { name: 'database' }
];
EndpointsIndex.flags = {
    app: command_1.flags.app({ required: true })
};
EndpointsIndex.examples = [
    '$ heroku data:privatelink postgresql-sushi-12345',
];
exports.default = EndpointsIndex;
