"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@heroku-cli/command");
const cli_ux_1 = require("cli-ux");
const base_1 = require("../../../base");
const fetcher_1 = require("../../../lib/fetcher");
class EndpointsWait extends base_1.default {
    async run() {
        const { args, flags } = this.parse(EndpointsWait);
        const database = await fetcher_1.default(this.heroku, args.database, flags.app);
        let status;
        cli_ux_1.cli.action.start('Waiting for the privatelink endpoint to be provisioned');
        while (status !== 'Operational') {
            let { body: res } = await this.shogun.get(`/private-link/v0/databases/${database}`, this.shogun.defaults);
            status = res.status;
            await cli_ux_1.cli.wait(3000);
        }
        cli_ux_1.cli.action.stop();
    }
}
EndpointsWait.description = 'wait for your privatelink endpoint to be provisioned';
EndpointsWait.aliases = ['pg:privatelink:wait', 'kafka:privatelink:wait', 'redis:privatelink:wait'];
EndpointsWait.args = [
    { name: 'database' }
];
EndpointsWait.flags = {
    app: command_1.flags.app({ required: true })
};
EndpointsWait.examples = [
    '$ heroku data:privatelink:wait postgresql-sushi-12345',
];
exports.default = EndpointsWait;
